@@ -24,13 +24,12 @@ import click
 
 from iotexetl.cli.export_blocks import export_blocks
 from iotexetl.cli.export_transaction_logs import export_transaction_logs
-from iotexetl.cli.export_logs import export_logs
 from iotexetl.cli.get_block_range_for_date import get_block_range_for_date
 from iotexetl.cli.stream import stream
 
 
 @click.group()
-@click.version_option(version='0.0.11')
+@click.version_option(version='1.0.0')
 @click.pass_context
 def cli(ctx):
     pass
@@ -39,7 +38,6 @@ def cli(ctx):
 # export
 cli.add_command(export_blocks, "export_blocks")
 cli.add_command(export_transaction_logs, "export_transaction_logs")
-cli.add_command(export_logs, "export_logs")
 
 # streaming
 cli.add_command(stream, "stream")
